@@ -1,6 +1,6 @@
 #!/usr/bin/env bash
 #
-# Copyright (C) 2017 Alexey Kopytov <akopytov@gmail.com>
+# Copyright (C) 2017-2018 Alexey Kopytov <akopytov@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -49,14 +49,12 @@ PACKPACK_REPO=${PACKPACK_REPO:-akopytov/packpack}
 distros_x86_64=(
     "el 6 x86_64"
     "el 7 x86_64"
-    "fedora 25 x86_64"
-    "fedora 26 x86_64"
     "fedora 27 x86_64"
+    "fedora 28 x86_64"
     "ubuntu trusty x86_64"
     "ubuntu xenial x86_64"
-    "ubuntu zesty x86_64"
     "ubuntu artful x86_64"
-    "debian wheezy x86_64"
+    "ubuntu bionic x86_64"
     "debian jessie x86_64"
     "debian stretch x86_64"
 )
@@ -64,19 +62,18 @@ distros_x86_64=(
 distros_i386=(
     "ubuntu trusty i386"
     "ubuntu xenial i386"
-    "ubuntu zesty i386"
     "ubuntu artful i386"
-    "debian wheezy i386"
+    "ubuntu bionic i386"
     "debian jessie i386"
     "debian stretch i386"
 )
 
 distros_aarch64=(
     "el 7 aarch64"
-    "fedora 25 aarch64"
-    "fedora 26 aarch64"
     "fedora 27 aarch64"
+    "fedora 28 aarch64"
     "ubuntu artful aarch64"
+    "ubuntu bionic aarch64"
     "ubuntu trusty aarch64"
     "ubuntu xenial aarch64"
     "debian jessie aarch64"
